@@ -256,7 +256,7 @@ void AudioControlPage::AddChannel(int channelnumber)
 	}
 	audioSizer->Add(sizer, 0, wxEXPAND | wxRIGHT, 10);
 
-	for (int i = wxEVT_SCROLL_TOP; i <= wxEVT_SCROLL_ENDSCROLL; ++i) {
+	for (int i = wxEVT_SCROLL_TOP; i <= wxEVT_SCROLL_CHANGED; ++i) {
 		Connect(FIRSTAUDIOSLIDER + channelnumber, i,
 		        (wxObjectEventFunction)(wxEventFunction)(wxCommandEventFunction)&AudioControlPage::OnChangeVolume);
 	}
@@ -282,20 +282,15 @@ void AudioControlPage::OnChangeMode(wxCommandEvent& event)
 	const wxString& channelname = m_audioChannels[id - FIRSTAUDIOCOMBO].name;
 	const wxString tempval = ((wxComboBox*)event.GetEventObject())->GetValue();
 	wxString value;
-	switch (tempval[0]) {
-	case 'M':
-		value = wxT("0");    break;
-	case 'L':
-		value = wxT("-100"); break;
-	case 'R':
-		value = wxT("100");  break;
-	case 'O':
-		value = wxT("mute"); break;
-	case 'S':
-		value = wxT("0");    break; // unmute
-	default:
-		break;
-	}
+	if (tempval[0] == wxT('M') || tempval[0] == wxT('S')) { // unmute
+		value = wxT("0");
+	} else if (tempval[0] == wxT('L')) {
+		value = wxT("-100");
+	} else if (tempval[0] == wxT('R')) {
+		value = wxT("100");
+	} else if (tempval[0] == wxT('O')) {
+		value = wxT("mute");
+	} else assert(false);
 	if (value.IsNumber()) {
 		m_controller.WriteCommand(wxString::Format(
 			wxT("set %s_balance %s"), channelname.c_str(), value.c_str()));
@@ -537,7 +532,7 @@ void AudioControlPage::OnBrowseMidiInFile(wxCommandEvent& event)
 {
 	auto* miditext = (wxTextCtrl*)FindWindowByName (wxT("MidiInFileInput"));
 	wxString defaultpath = ::wxPathOnly(miditext->GetValue());
-	wxFileDialog filedlg(this, wxT("Select MIDI input file"), defaultpath, wxT(""), wxT("*.*"), wxOPEN);
+	wxFileDialog filedlg(this, wxT("Select MIDI input file"), defaultpath, wxT(""), wxT("*.*"), wxFD_OPEN);
 	if (filedlg.ShowModal() == wxID_OK) {
 		miditext->SetValue (filedlg.GetPath());
 		if (!miditext->GetValue().IsEmpty()) {
@@ -550,7 +545,7 @@ void AudioControlPage::OnBrowseMidiOutFile(wxCommandEvent& event)
 {
 	auto* miditext = (wxTextCtrl*)FindWindowByName(wxT("MidiOutFileInput"));
 	wxString defaultpath = ::wxPathOnly(miditext->GetValue());
-	wxFileDialog filedlg(this, wxT("Select MIDI output file"), defaultpath, wxT(""), wxT("*.*"), wxSAVE | wxOVERWRITE_PROMPT);
+	wxFileDialog filedlg(this, wxT("Select MIDI output file"), defaultpath, wxT(""), wxT("*.*"), wxFD_SAVE | wxFD_OVERWRITE_PROMPT);
 	if (filedlg.ShowModal() == wxID_OK) {
 		miditext->SetValue(filedlg.GetPath());
 		if (!miditext->GetValue().IsEmpty()) {
@@ -563,7 +558,7 @@ void AudioControlPage::OnBrowseSampleInFile(wxCommandEvent& event)
 {
 	auto* sampletext = (wxTextCtrl*)FindWindowByName(wxT("SampleFileInput"));
 	wxString defaultpath = ::wxPathOnly(sampletext->GetValue());
-	wxFileDialog filedlg(this, wxT("Select PCM sample input file"), defaultpath, wxT(""), wxT("*.*"), wxOPEN);
+	wxFileDialog filedlg(this, wxT("Select PCM sample input file"), defaultpath, wxT(""), wxT("*.*"), wxFD_OPEN);
 	if (filedlg.ShowModal() == wxID_OK) {
 		sampletext->SetValue(filedlg.GetPath());
 		if (!sampletext->GetValue().IsEmpty()) {
