@@ -27,6 +27,7 @@
 #include <wx/statusbr.h>
 #include <wx/wxprec.h>
 #include <wx/xrc/xmlres.h>
+#include <sstream>
 
 // TODO: why is this define needed?
 #define unisprintf sprintf
@@ -122,7 +123,7 @@ wxCatapultFrame::wxCatapultFrame(wxWindow* parent)
 	settingsMenu->Append(Catapult_Save_OpenMSX_Settings_As, wxT("Save openMSX Settings &As..."), wxT("Save All openMSX settings to a specified file"));
 	settingsMenu->AppendCheckItem(Catapult_Save_On_Exit, wxT("Save openMSX Settings On &Exit"), wxT("Save All openMSX settings as soon as openMSX is closed"));
 	viewMenu->AppendCheckItem(Catapult_Display_Invalids, wxT("Display Broken Configurations"), wxT("Display all machines and extension even if they don't work"));
-	helpMenu->Append(Catapult_About, wxT("&About\tCtrl-A"), wxT("Show about dialog"));
+	helpMenu->Append(Catapult_About, wxT("About"), wxT("Show about dialog"));
 
 	auto& config = ConfigurationData::instance();
 
@@ -255,11 +256,7 @@ void wxCatapultFrame::OnMenuAbout(wxCommandEvent& event)
 	version->SetLabel(wxString(Version::FULL_VERSION.c_str(), wxConvUTF8));
 	description->SetLabel(wxT("The official GUI for openMSX"));
 	message->SetLabel(wxT("\251 2003-2014 The openMSX Team\n<openmsx-devel@lists.sourceforge.net>\n"));
-#ifdef __WXMSW__
-		dlg.SetSize(-1, -1, 400, 307, 0);
-#else
-		dlg.SetSize(-1, -1, 400, 300, 0);
-#endif
+	dlg.Fit();
 	dlg.CenterOnParent();
 	dlg.ShowModal();
 }
@@ -287,14 +284,8 @@ bool wxCatapultFrame::EditConfig(bool fatalIfFails)
 
 void wxCatapultFrame::OnMenuLoadSettings(wxCommandEvent& event)
 {
-	wxString path;
-#ifndef __MOTIF__
-	path = wxT("Configuration Files(*.xml)|*.xml;*.XML|All files|*.*||");
-#else
-	path = wxT("*.*");
-#endif
-
-	wxFileDialog filedlg(this, wxT("Select configuration file"), wxT(""), wxT(""), path, wxOPEN);
+	wxString path = wxT("Configuration Files(*.xml)|*.xml;*.XML|All files|*.*||");
+	wxFileDialog filedlg(this, wxT("Select configuration file"), wxT(""), wxT(""), path, wxFD_OPEN);
 	if (filedlg.ShowModal() == wxID_OK) {
 		wxString settingsfile = filedlg.GetPath();
 		if (m_controller->IsOpenMSXRunning()){
@@ -318,14 +309,8 @@ void wxCatapultFrame::OnMenuSaveSettings(wxCommandEvent& event)
 
 void wxCatapultFrame::OnMenuSaveSettingsAs(wxCommandEvent& event)
 {
-	wxString path;
-#ifndef __MOTIF__
-	path = wxT("Configuration Files(*.xml)|*.xml;*.XML|All files|*.*||");
-#else
-	path = wxT("*.*");
-#endif
-
-	wxFileDialog filedlg(this, wxT("Select file to save to"), wxT(""), wxT(""), path, wxSAVE | wxOVERWRITE_PROMPT);
+	wxString path = wxT("Configuration Files(*.xml)|*.xml;*.XML|All files|*.*||");
+	wxFileDialog filedlg(this, wxT("Select file to save to"), wxT(""), wxT(""), path, wxFD_SAVE | wxFD_OVERWRITE_PROMPT);
 	if (filedlg.ShowModal() == wxID_OK) {
 		wxString settingsfile = filedlg.GetPath();
 		m_controller->WriteCommand(wxT("save_settings ") + utils::ConvertPath(settingsfile));
@@ -396,59 +381,16 @@ void wxCatapultFrame::OnLaunch(wxCommandEvent& event)
 	m_launch_AbortButton->Enable(false);
 	m_safetyTimer.Start(2000, true); // max 2 seconds disable (whatever happens)
 
-	wxArrayString patches[5];
-	m_sessionPage->getPatches(patches);
-	wxArrayString hardware = m_sessionPage->getHardware();
-	wxArrayString media    = m_sessionPage->getMedia();
-	wxArrayString types    = m_sessionPage->getTypes();
-
 	wxString cmd;
 	config.GetParameter(ConfigurationData::CD_EXECPATH, cmd);
 	if (!m_settingsfile.IsEmpty()) {
 		cmd += wxT(" -setting ") + utils::ConvertPath(m_settingsfile);
 	}
-	if (hardware[0] != wxT(" <default> ")) { // Ooooww.... we're using representation here as useful data! :(
-		cmd += wxT(" -machine ") + hardware[0];
-	}
+	cmd += wxT(" ") + m_sessionPage->getStartupCommandLineOptions();
 
-	// EXTENSIONS start from index 1 in hardware!
-
-	// Here's a hack to make sure that slotexpander is always mentioned first. Note that this will break terribly if someone renames the slotexpander extension. Hence the 'hack' remark.
-	unsigned i = hardware.Index(wxT("slotexpander"), false);
-
-	if ((int)i != wxNOT_FOUND) {
-		// put it at item 1
-		hardware.RemoveAt(i);
-		hardware.Insert(wxT("slotexpander"), 1);
-	}
-
-	if (hardware.GetCount() > 1) {
-		for (i = 1; i < hardware.GetCount(); ++i) {
-			cmd += wxT(" -ext ") + hardware[i];
-		}
-	}
-	wxString parmname [5] = {
-		wxT("diska"), wxT("diskb"), wxT("cart"), wxT("cart"),
-		wxT("cassetteplayer")
-	};
-	for (unsigned i = 0; i < 5; ++i) {
-		if (!media[i].IsEmpty()) {
-			cmd += wxT(" -") + parmname[i] + wxT(" \"") + media[i] + wxT("\"");
-			if (!types[i].IsEmpty()){
-				cmd += wxT(" -romtype ") + types[i];
-			}
-			size_t count = patches[i].GetCount();
-			if (count != 0) {
-				for (size_t j = 0; j < count; ++j) {
-					cmd += wxT(" -ips \"") + patches[i].Item(j) + wxT("\"");
-				}
-			}
-		}
-	}
-	m_sessionPage->UpdateSessionData();
 	m_statusPage->Clear();
 
-	Enable(false); // Disable this frame only after getting the selections (so, also AFTER UpdateSessionData!)
+	Enable(false); // Disable this frame only after getting the selections
 
 	SetControlsOnLaunch();
 	m_controller->StartOpenMSX(cmd);
@@ -519,11 +461,19 @@ void wxCatapultFrame::StopTimers()
 void wxCatapultFrame::OnUpdateFPS(wxTimerEvent& event)
 {
 	m_controller->WriteCommand(wxT("openmsx_info fps"),
-		[&](const wxString&, const wxString& r) {
+		[&](const wxString& c, const wxString& r) {
+			// convert wxString -> double using C locale
+			//  (so use '.' as decimal point)
+			// The wxString::ToDouble() method uses the current
+			// locale and for some reason wxWidgets changes the
+			// default locale (or doesn't use the C locale like
+			// most c/c++ programs).
 			double val;
-			if (r.ToDouble(&val)) {
+			std::stringstream ss(std::string(r.ToAscii()));
+			ss >> val;
+			//if (r.ToCDouble(&val)) { // requires wxWidgets-2.9
 				SetStatusText(wxString::Format(wxT("%2.1f fps"), val), 1);
-			}
+			//}
 		});
 }
 
